********************************************************************************
*** ARtHEE Phase 1 ESR-Paper
*** Basic_Recodes.do
***
*** Steffen Schindler & Felix Bittmann
*** 2021
********************************************************************************


********************************************************************************
*** info from Basics ***
********************************************************************************
/*We start by extracting basic sociodemographic information, that is already
collected in the Basics file by the NEPS team. We recode some relevant variables,
for example EGP to form three classes. This gives us the most important
information about respondents.
*/

* year of birth
* month of birth counting from 1900
* sex
* EGP parents
* ISEI parents
* migratory status
* born in east Germany

cd "$data"
use SC6_Basics_D_10-0-1.dta, clear

* year of birth
gen byear=t70000y
lab var byear "year of birth"

* month of birth counting from 1900
gen bmonth=(t70000y-1900)*12+t70000m
lab var bmonth "month of birth (counting from 1900)"

* sex
recode t700001 (1=0 "Mann") (2=1 "Frau"), gen(female)
tab t700001 female, miss
label var female "[P] Person ist weiblich"

* EGP parents
recode t731403_g8 (1 2 = 3 "Service Class") (3 8 5 6 7 = 2 "Middle Class") ///
	(4 9 10 11 = 1 "Working Class"), gen(temp1)
tab t731403_g8 temp1, miss
recode t731453_g8 (1 2 = 3 "Service Class") (3 8 5 6 7 = 2 "Middle Class") ///
	(4 9 10 11 = 1 "Working Class"), gen(temp2)
egen temp3 = rowmax(temp1 temp2)
bysort ID_t: egen maxegp = max(temp3)
drop temp1 temp2 temp3
label var maxegp "[P] Max. Parental EGP"
label define maxegp 3 "Service Class" 2 "Middle Class" 1 "Working Class"
label values maxegp maxegp

* ISEI parents
cap drop temp
egen temp = rowmax(t731403_g5 t731453_g5)
bysort ID_t: egen maxisei = max(temp)
drop temp
label var maxisei "[P] Max. Parental ISEI"

* Migratory status: born in GER or immigrated before the age of 7
gen mig6=0
replace mig6=1 if tx29005==1 | (tx29007<7 & tx29007>0)
lab var mig6 "Born in GER or immigrated before the age of 7"

* Born in East Germany
gen east=0
replace east=1 if t405000_g2==2
lab var east "Born in East Germany"

* keep  
keep ID_t byear bmonth female maxegp maxisei mig6 east

* save
cd "$recoded"
save basic.dta, replace


********************************************************************************
*** info from spSchool ***
********************************************************************************
/*Here we need to look at the schooling history of respondets, which is
collected in the school spell dataset by the NEPS team. We need to know which
type of qualification was obtained by the respondents and when. This is important
to check which is the highest qualification ever obtained and when this happened.
We also use this information to check the quality of the results and excluded
respondents with nonsensical information (for example, obtaining a high
qualification at a very young age, which is practically impossible.
*/

* type of higher education entrance qualification
* month of heeq counting from 1900

cd "$data"
use SC6_spSchool_D_10-0-1.dta, clear

* type of heeq
lab def htype 99"unknown" 0"none" 1"restricted (FHR)" 2"other alternative" 3"full (AHR)"
gen htype=99
replace htype=0 if inlist(ts11209,-21,-20,1,2,3,6)
replace htype=1 if ts11209==4
replace htype=3 if ts11209==5
replace htype=2 if (ts11209==5 & ts11211==1)
lab val htype htype

* type of school where heeq obtained
lab def schooltype 99"unknown" 0"no heeq school" 1"alternative" 2"Gymnasium"
gen schooltype=99
replace schooltype=0 if inlist(ts11204_v1,1,2,3,8) | inlist(ts11204,1,2,3,4,5,6,7,12) | inlist(ts11204_ha,1,2,7) | inlist(ts11205,1,3,5,6,7,8,9)
replace schooltype=2 if inlist(ts11204,8,9) | inlist(ts11205,11,18) 
replace schooltype=1 if inlist(ts11204_v1,4,5) | inlist(ts11204,10,11,13) | inlist(ts11204_ha,3,4,6) | inlist(ts11205,12,13,14,15,16,17,19,20,21,22,23,24,25,26,27) 
lab val schooltype schooltype 

* not clear if Gymnasium or alternative school
gen uncl_school=1 if ((ts11204_ha==5 | ts11204_v1==6) & ts11205==-54) 
lab var uncl_school "unclear if Gymnasium or alternative school"

gen uncl_type=1 if (!inlist(ts11211,1,2) & ts11209==5)
lab var uncl_type "unclear if full or alternative heeq" 

* implausible combination of schooltype and type of heeq
gen implau=1 if inlist(htype,1,2,3) & schooltype==0 
lab var implau "implausible combination of schooltype and heeq"

* categorizing type of heeq
lab def heeq 0"none" 1"restricted (FHR)" 2"full alternative (AHR)" 3"full alternative or Gymnasium (AHR)" 4"full Gymnasium (AHR)"
gen heeq=.
replace heeq=0 if htype==0 | schooltype==0
replace heeq=1 if htype==1
replace heeq=2 if (htype==2 & inlist(schooltype,1,2,99)) | (htype==3 & schooltype==1)
replace heeq=3 if (htype==3 & schooltype==99) 
replace heeq=3 if (htype==3 & uncl_school==1) /* check: 0 changes to be expected */
replace heeq=4 if htype==3 & schooltype==2
lab val heeq heeq
lab var heeq "type of higher education entrance qualitfication"
  
* month beginning of spell (counting from 1900)
replace ts1111m=ts1111m-20 if ts1111m>12
replace ts1111m=6 if ts1111m<0
gen bmonth=(ts1111y-1900)*12+ts1111m if ts1111y>0
lab var bmonth "month beginning of spell (counting from 1900)"

* month end of spell (counting from 1900)
replace ts1112m=ts1112m-20 if ts1112m>12
replace ts1112m=6 if ts1112m<0
gen emonth=(ts1112y-1900)*12+ts1112m if ts1112y>0
lab var emonth "month end of spell (counting from 1900)"

* identify highest school certificate per ID
bys ID_t: egen heeqmax=max(heeq)
lab val heeqmax heeq 

* identify most recent month of highest school certificate  
gen date=emonth if heeqmax==heeq
bys ID_t: egen datemax=max(date) 
gen tag=1 if date==datemax

* more precise allocation of observations in category heeq=3"full alternative or Gymnasium (AHR)"
// problem: ts11204_v1=6 and ts11204_ha==5 --> unclear if Gymnasium or alternative schooltype 
// solution: ID will be assigned to heeq=4"full Gymnasium (AHR)" if
//           - ID is in category heeq=3
//           - ID spent more than 4 consecutive years in ts11204_v1=6 or ts11204==8 or ts11204_ha==5 (=unclear if Gymnasium) 
gen gym=.
replace gym=1 if ts11204_v1==6 | ts11204==8 | ts11204_ha==5 
gen gymdur=emonth-bmonth if gym==1
bys ID_t: egen gymdurmax=max(gymdur)
replace heeqmax=4 if heeqmax==3 & gymdurmax>48

* final recode of type of heeq 
lab def heeq_a 0"none" 1"restricted (FHR)" 2"full alternative (AHR)" 3"full Gymnasium (AHR)"
gen heeq_a=heeqmax
recode heeq_a 0=0 1=1 2 3=2 4=3
lab val heeq_a heeq_a
lab var heeq_a "type of higher education entrance qualitfication"

* keep
ren datemax date_a
lab var date_a "month higher education entrance qualitfication (counting from 1900)"
keep if tag==1
bys ID_t: gen n=_N // remove duplicates
keep if n==1
keep ID_t heeq_a date_a 

* save
cd "$recoded"
save spSchool.dta, replace


********************************************************************************
*** info from spSchoolExtExam ***
********************************************************************************
/*In this file we add information about the type of qualification obtained, which
is separate. For example, some school types offer multiple qualifications so
it is not clear which type has been obtained.
*/

* type of higher education entrance qualification
* month of heeq counting from 1900

cd "$data"
use SC6_spSchoolExtExam_D_10-0-1.dta, clear


* month end of spell (counting from 1900)
replace ts1130m=ts1130m-20 if ts1130m>12
replace ts1130m=6 if ts1130m<0
gen date_b=(ts1130y-1900)*12+ts1130m if ts1130y>0
lab var date_b "month end of spell (counting from 1900)"

* type of heeq 
lab def heeq_b 0"none" 1"restricted (FHR)" 2"full alternative (AHR)" 3"full Gymnasium (AHR)"
gen heeq_b=.
replace heeq_b=1 if ts11302==4
replace heeq_b=2 if ts11302==5
keep if heeq_b!=.
lab val heeq_b heeq_b

* keep
keep ID_t heeq_b date_b 

* reshape
sort ID_t date_b 
bys ID_t: gen n=_n
reshape wide heeq_b date_b, i(ID_t) j(n)
lab var date_b1 "month higher education entrance qualitfication (counting from 1900)"
lab var date_b2 "month higher education entrance qualitfication (counting from 1900)"
lab var heeq_b1 "type of higher education entrance qualitfication"
lab var heeq_b2 "type of higher education entrance qualitfication"

* save
cd "$recoded"
compress
save spSchoolExtExam.dta, replace


********************************************************************************
*** info from spVocTrain ***
********************************************************************************
/*Finally we add information about any type of education that was obtained after
schooling, so either vocational qualifications or tertiary degrees. This information
is also recoded and added to the respondents.
*/

* higher education entrance qualification (Eignungsprüfung o.ä.)
* higher education attendance
* month of first higher education spell
* higher education degree
* month of last higher education degree

cd "$data"
use SC6_spVocTrain_D_10-0-1.dta, clear

* month beginning of spell (counting from 1900)
replace ts1511m=ts1511m-20 if ts1511m>12
replace ts1511m=6 if ts1511m<0
gen bmonth=(ts1511y-1900)*12+ts1511m if ts1511y>0
lab var bmonth "month beginning of spell (counting from 1900)"

* month end of spell (counting from 1900)
replace ts1512m=ts1512m-20 if ts1512m>12
replace ts1512m=6 if ts1512m<0
gen emonth=(ts1512y-1900)*12+ts1512m if ts1512y>0
lab var emonth "month end of spell (counting from 1900)"

* heeq test
gen heeqt=0
replace heeqt=1 if inrange(ts15205,1,3)
bys ID_t: egen heeq_c=max(heeqt)
lab var heeq_c "higher education entrance qualification through test etc."

* month of first heeq test (counting from 1900)
gen testmonth=bmonth if heeqt==1
bys ID_t: egen date_c=min(testmonth)
lab var date_c "month of heeq test (counting from 1900)"

* attended higher education 
gen he_attend_=0
replace he_attend_=1 if inlist(ts15201_v1,5,6,7) | inlist(ts15201,6,7,8,9,10) | ts15204==1
bys ID_t: egen he_attend=max(he_attend_)
lab var he_attend "attended higher education"

* month of first HE spell (counting from 1900)
gen hemonth=bmonth if he_attend_==1
bys ID_t: egen he_first=min(hemonth)
lab var he_first "month of first HE spell (counting from 1900)"

* higher education degree
gen he_degree_=0
replace he_degree_=1 if inrange(ts15219_v1,6,16) | inrange(ts15219_ha,6,11) | inrange(ts15219,7,22) | inlist(ts15911,1,2)
bys ID_t: egen he_degree_a=max(he_degree_)
lab var he_degree_a "higher education degree"

* month of last HE degree (counting from 1900)
gen degreemonth=bmonth if he_degree_==1
bys ID_t: egen he_last_a=max(degreemonth)
lab var he_last_a "month of last HE degree (counting from 1900)"

* keep
bys ID_t: gen n=_n
keep if n==1
keep ID_t heeq_c date_c he_attend he_first he_degree_a he_last_a

* save
cd "$recoded"
compress
save spVocTrain.dta, replace


********************************************************************************
*** info from spVocExtExam ***
********************************************************************************

* higher education degree
* month of last higher education degree

cd "$data"
use SC6_spVocExtExam_D_10-0-1.dta, clear

* higher education degree
gen he_degree_=0
replace he_degree_=1 if inrange(ts15304,7,22) | inrange(ts15304_v1,6,16) 
bys ID_t: egen he_degree_b=max(he_degree_)
lab var he_degree_b "higher education degree"

* month of last HE degree (counting from 1900)
replace ts1530m=ts1530m-20 if ts1530m>12
replace ts1530m=6 if ts1530m<0
gen degreemonth=(ts1530y-1900)*12+ts1530m if ts1530y>0 & he_degree_==1
bys ID_t: egen he_last_b=max(degreemonth)
lab var he_last_b "month of last HE degree (counting from 1900)"

* keep
bys ID_t: gen n=_n
keep if n==1
keep ID_t he_degree_b he_last_b

* save
cd "$recoded"
compress
save spVocExtExam.dta, replace


********************************************************************************
exit 



