********************************************************************************
*** ARtHEE Phase 1 ESR-Paper
*** Merge_clean.do
***
*** Steffen Schindler & Felix Bittmann
*** 2021
********************************************************************************


********************************************************************************
*** merge data ***
********************************************************************************
/*After preparing and recoding the information in basic_recodes.do, we now
merge all information together, based on the ID of each respondent.
*/

cd "$recoded"

use basic.dta, clear
merge 1:1 ID_t using spSchool.dta, nogen
merge 1:1 ID_t using spSchoolExtExam.dta, nogen
merge 1:1 ID_t using spVocTrain.dta, nogen
merge 1:1 ID_t using spVocExtExam.dta, nogen
cd "$data"
merge m:1 ID_t using "SC6_Weights_D_10-0-1.dta", nogen


********************************************************************************
*** sample selection ***
********************************************************************************
recode byear (1940/1950=0 "1940-50") (1965/1980=1 "1965-80") ///
	(9999=2 "simulation") (else=.), into(testcohort)		//Test, kann raus

* born in GER or immigrated before the age of 7
keep if mig6==1

* born in West-GER or immigrated before the age of 7
drop if east==1  // Attention: we do not know whether immigrants grew up in West or East Germany


********************************************************************************
*** plausibility checks and corrections ***
********************************************************************************
/*At this point we apply heuristics to account for errors in the data. We know
by experience that this is the case and we sometimes see blatant errors, which
are either impossible or nonsensical. So our results are not affected by them,
we try to remove them. Doing this manually is not feasible due to the large number
of respondents and the complex schooling histories. The idea is hence to throw out
cases that have nonsensical, impossible or very strange schooling histories.
We look especially at dates and certificates. Some combinations are, for example,
impossible (having a tertiary degree before a secondary schooling degree or
having a secondary schooling degree at a very young age. Some respondents also
report a tertiary degree but no secondary degree, which is also impossible in
reality.
*/

* age at school certificate and higher education entrance qualification
foreach n of newlist a b1 b2 c{
   gen age_`n'=(date_`n'-bmonth)/12
   gen heeq_age_`n'=(date_`n'-bmonth)/12 if inrange(heeq_`n',1,3) 
   }

* set to missing if too young for school certificate 
foreach n of newlist a b1 b2{    
   replace heeq_`n'=. if age_`n'<10               /* any school certificate below age 10 */
   replace heeq_`n'=. if heeq_age_`n'<17          /* any heeq below age of 17 */
   }
replace heeq_c=. if age_c<15                      /* any heeq test/Begabtenprüfung/berufliche Anerkennung below age of 15 */

* adjust missing values based on previous corrections
foreach n of newlist a b1 b2 c{
   replace age_`n'=. if heeq_`n'==. 
   replace heeq_age_`n'=. if heeq_`n'==. 
   }

* date heeq vs. date higher education attendance
foreach n of newlist a b1 b2 c{
   gen heeq_date_`n'=date_`n' if inrange(heeq_`n',1,3)  
   }
egen heeq_date_min=rowmin(heeq_date_a heeq_date_b1 heeq_date_b2 heeq_date_c)
gen datediff_1=(he_first-heeq_date_min)/12
egen he_degree_max=rowmax(he_last_a he_last_b)
gen datediff_2=(he_degree_max-heeq_date_min)/12
drop if datediff_1<-2                            // drop observation if first heeq more than 2 years after HE enrolment
drop if datediff_1<0                             // drop observation if last HE graduation before heeq 


* highered but no heeq
egen heeqtemp=rowmax(heeq_a heeq_b1 heeq_b2 heeq_c)
recode heeqtemp 0=0 1/3=1
egen hedetemp=rowmax(he_degree_a he_degree_b)
ta heeqtemp he_attend,m
ta heeqtemp hedetemp,m
gen implaus=1 if heeqtemp==0 & (he_attend==1 | hedetemp==1)
lab var implaus "highered but no heeq"
drop if implaus==1                              // drop observation if higher education attendance/degree but no heeq

* adjust to old recodes and vars
egen temp=rowmax(heeq_a heeq_b1 heeq_b2)
recode temp (0=4 "none") (1=2 "restricted") (2=3 "alternative") (3=1 "Gymnasium"), into(hzbart)
drop temp
gen tertstart=he_attend
gen tertabschluss=hedetemp

* alternative: case by case correction
*cd "$do"
*do Einzelfaelle_2020_2.do // case by case correction (only cohorts 1944/50 and 1963/86)
*tab hzbart tertstart if (inrange(byear,1944,1950) | inrange(byear,1963,1986)) & inrange(maxegp,1,3), m
*tab hzbart tertabschluss if (inrange(byear,1944,1950) | inrange(byear,1963,1986)) & inrange(maxegp,1,3), m



recode hzbart (1 2 3 = 1 "HZB") (4 = 0 "No HZB"), gen(anyhzb)
tab hzbart anyhzb, miss

********************************************************************************
*** safe ***
********************************************************************************


cd "$recoded"
compress
save merged.dta, replace

********************************************************************************
exit 











